@@ -1,4 +1,3 @@
-
 import gettext
 import locale
 import os
@@ -6,16 +5,18 @@ import sys
 
 sys_lang_code = locale.getdefaultlocale()[0]
 locale_path = locale_dir_path = os.path.abspath(os.path.dirname(__file__))
-locale_langcodes =  \
-    [d for d in os.listdir(locale_path)
-     if os.path.isdir(os.path.join(locale_path, d))]
+locale_langcodes = [
+    d
+    for d in os.listdir(locale_path)
+    if os.path.isdir(os.path.join(locale_path, d))
+]
 
 if sys_lang_code not in locale_langcodes:
-    sys_lang_code = 'en_US'
+    sys_lang_code = "en_US"
 
 lang = gettext.translation(
-    'primaryschool', localedir=locale_path,
-    languages=[sys_lang_code])
+    "primaryschool", localedir=locale_path, languages=[sys_lang_code]
+)
 
 lang.install()
 
